==> xmpp-core-common-0.8.1-sources.jar: rocks/xmpp/util/adapters/LocaleAdapter.java <==
/*
 * The MIT License (MIT)
 *
 * Copyright (c) 2014-2016 Christian Schudt
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */

package rocks.xmpp.util.adapters;

import javax.xml.bind.annotation.adapters.XmlAdapter;
import java.util.Locale;

/**
 * Converts an {@link Locale} to a string representation using {@link Locale#toLanguageTag()} and vice versa, using {@link Locale#forLanguageTag(String)}}.
 *
 * @author Christian Schudt
 */
public final class LocaleAdapter extends XmlAdapter<String, Locale> {
    @Override
    public final Locale unmarshal(String v) {
        return v != null ? Locale.forLanguageTag(v) : null;
    }

    @Override
    public final String marshal(Locale v) {
        return v != null ? v.toLanguageTag() : null;
    }
}

==> xmpp-core-common-0.9.0-sources.jar: rocks/xmpp/util/adapters/LocaleAdapter.java <==
/*
 * The MIT License (MIT)
 *
 * Copyright (c) 2014-2016 Christian Schudt
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */

package rocks.xmpp.util.adapters;

import java.util.Locale;
import javax.xml.bind.annotation.adapters.XmlAdapter;

/**
 * Converts an {@link Locale} to a string representation using {@link Locale#toLanguageTag()} and vice versa, using
 * {@link Locale#forLanguageTag(String)}}.
 *
 * @author Christian Schudt
 */
public final class LocaleAdapter extends XmlAdapter<String, Locale> {

    @Override
    public final Locale unmarshal(String v) {
        return v != null ? Locale.forLanguageTag(v) : null;
    }

    @Override
    public final String marshal(Locale v) {
        return v != null ? v.toLanguageTag() : null;
    }
}
